@@ -6,8 +6,8 @@
 ;; Author: Johnson Denen <johnson.denen@gmail.com>
 ;;         Marty Hiatt <mousebot@disroot.org>
 ;; Maintainer: Marty Hiatt <mousebot@disroot.org>
-;; Version: 2.0.1
-;; Package-Requires: ((emacs "28.1") (persist "0.4") (tp "0.7"))
+;; Version: 2.0.3
+;; Package-Requires: ((emacs "28.1") (persist "0.7") (tp "0.7"))
 ;; Homepage: https://codeberg.org/martianh/mastodon.el
 
 ;; This file is not part of GNU Emacs.
@@ -267,6 +267,7 @@ Also nil `mastodon-auth--token-alist'."
     (define-key map (kbd ",")      #'mastodon-toot-list-favouriters)
     (define-key map (kbd ".")      #'mastodon-toot-list-boosters)
     (define-key map (kbd ";")      #'mastodon-views-view-instance-description)
+    (define-key map (kbd "M-;")    #'mastodon-tl-nodeinfo-for-toot)
     ;; override special mode binding
     (define-key map (kbd "g")      #'undefined)
     (define-key map (kbd "g")      #'mastodon-tl-update)
@@ -495,14 +496,14 @@ If FORCE, do a lookup regardless of the result of `mastodon--fedi-url-p'."
   (interactive)
   (mastodon-url-lookup nil :force))
 
-(defun mastodon--fedi-url-p (query)
+(defun mastodon--fedi-url-p (url)
   "Check if QUERY resembles a fediverse URL."
   ;; calqued off https://github.com/tuskyapp/Tusky/blob/c8fc2418b8f5458a817bba221d025b822225e130/app/src/main/java/com/keylesspalace/tusky/BottomSheetActivity.kt
   ;; thx to Conny Duck!
   ;; mastodon at least seems to allow only [a-z0-9_] for usernames, plus "."
   ;; but not at beginning or end, see https://github.com/mastodon/mastodon/issues/6830
   ;; objects may have - in them
-  (let* ((uri-parsed (url-generic-parse-url query))
+  (let* ((uri-parsed (url-generic-parse-url url))
          (query (url-filename uri-parsed)))
     (save-match-data
       (or (string-match "^/@[^/]+$" query)
@@ -523,7 +524,8 @@ If FORCE, do a lookup regardless of the result of `mastodon--fedi-url-p'."
           (string-match "^/user[s]?/[[:alnum:]_]+/statuses/[[:digit:]]+$" query) ; hometown
           (string-match "^/notes/[[:alnum:]]+$" query) ; misskey post
           (string-match "^/w/[[:alnum:]_]+$" query) ; peertube post
-          ))))
+          ;; bsky via fed.brid.gy (unsure if this needs narrowing down?):
+          (string-prefix-p "https://fed.brid.gy/r/" url)))))
 
 (defun mastodon-live-buffers ()
   "Return a list of open mastodon buffers.
